#!/bin/perl
#################################################################################
# Created       : Martin Foster
# Modified      : 22-Jan-2004
#################################################################################
#
# Publish - Script used to re-publish all text works into PDF format.
# Copyright (C) 2000-2004  Martin Foster
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
# Author of this script can be contacted at the following:
#       E-Mail  : martin@ethereal-realms.org
#       Address : 29-26503 TWP RD 511
#                 Spruce Grove, Alberta
#                 T7Y 1G4
#
#################################################################################

use strict;							# Strict variable enforcement

use eRealms::Database;						# Database handler
use eRealms::Home;						# Homepage handler


#################################################################################
# Data Members
#################################################################################
my $database;							# Database handle
my $page;							# Page handle

my $res;							# Result handle
my $statement;							# Query
my $template;							# Template to use

my $tmp = '/tmp';						# Temporary directory

my %gal;							# Gallery
my %system;							# System hash

#################################################################################
# Program Area
#################################################################################

	# Initial handles
	$database = new eRealms::Database();

	# Connect and Fetch
	$database->Connect();

	# Associate with hash
	$database->GetHashGallery(\%gal);
	$database->GetHashSystem(\%system);


	# Create instance
	$page = new eRealms::Home($database, $tmp);


	# Fetch and export work
	($template) = $database->DocumentGetGalleryExport();
	
	# Contacts
	$database->Pull(\$statement, "SELECT 
		  g.GalleryPenName AS \"GalleryPenName\", 
		  g.GalleryName    AS \"GalleryName\", 
		  g.GalleryID      AS \"GalleryID\", 
		  w.WorkText       AS \"WorkText\", 
		  w.WorkID         AS \"WorkID\", 
		  w.WorkName       AS \"WorkName\"
		FROM ethereal.Gallery g, ethereal.Work w
		WHERE g.GalleryType='text'
		AND w.WorkText IS NOT NULL
		AND g.GalleryID=w.GalleryID
		ORDER BY g.GalleryID, w.WorkID");

	# Loop and publish
	# Continue as long as there are works
	while ($res = $statement->fetchrow_hashref())
	{
		# Publishing handler
		Publish($page, $res, $template, \%system, \%gal, $tmp);
	}

	# End
	$statement->finish();


#################################################################################
# Sub-Routines
#################################################################################

#####################
# Publish
#
# An exact copy of the code that is used in the gallery.pl file in order to
# publish works.   This one is self-contained as to prevent any chance of tainting
# information.

sub Publish
{
	#####################
	# Data members

	my $page     = shift;					# Page handler
	my $results  = shift;					# Results 
	my $export   = shift; 					# Changeable template
	my $system   = shift; 					# System hash
	my $gal      = shift; 					# Gallery hash
	my $tmp      = shift;					# Temporary directory

	my $data;						# Physical text
	my $dir;						# Directory to use

	
	#####################
	# Program area

	# Set directory
	$dir = $gal->{'SetRoot'} . '/' . $res->{'GalleryID'} . '/' . $res->{'WorkID'};


	# Safety
	mkdir($dir, 0775) unless (-d $dir);


	# Display progress
	print "$results->{GalleryID} - $results->{WorkID}: $results->{WorkName} BY $results->{GalleryPenName}\n";


	# Simple replacement
	$data =  $results->{'WorkText'};
	$data =~ s/\n/<BR>/gs;

	# Search and replace
	$export =~ s/MAUTHOR/$results->{'GalleryPenName'}/gs;
	$export =~ s/MGID/$results->{'GalleryID'}/gs;
	$export =~ s/MGNAME/$results->{'GalleryName'}/gs;
	$export =~ s/MGWORK/$results->{'WorkName'}/gs;
	$export =~ s/MTITLE/$results->{'WorkName'}/gs;
	$export =~ s/MWID/$results->{'WorkID'}/gs;
	$export =~ s/MBODY/$data/gs;
						
	# Write temporary file
	$page->FileWrite('export.html', $export);


	# Export to PDF
	if (-f "$tmp/export.html")
	{
		# Evaluate clause
		eval
		{
			# Execute command
			system("$system->{SetExport} $system->{SetExportOpt} $dir/work.pdf $tmp/export.html");
		};

		# If block failed
		if ($@)
		{
			# Issue warning
			warn("Error in export: $@");
		}
	}

	# Error
	else
	{
		# Display error
		print " $page->{BASEDIR}/export.html was not found!\n";
	}
}
